@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2019-2021 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -70,7 +70,13 @@ private Q_SLOTS:
             // needs it encoded which is a bit weird because it doesn't actually
             // require full-form encoding either (i.e. space becomes plus and
             // plus becomes encoded).
-            if (httpBlob.startsWith("GET /hi?informal=yes%2Bcertainly")) {
+            //
+            // This further broke because we force-recoded the query items but then that caused over-decoding (%FF)
+            // because QUrlQuery internally stores the DecodeReserved variant and we blindly FullDecode leading to the
+            // verbatim percent value getting decoded at the same time we can't DecodeReserved because that would
+            // still decode verbatim reserved sequences form the input password (e.g. the password containing %3C aka <).
+            // https://bugs.kde.org/show_bug.cgi?id=435442
+            if (httpBlob.startsWith("GET /hi?informal=yes%2Bcertainly&password=%253C___m%26T9zSZ%3E0%2Cq%25FFDN")) {
                 QFile file(QFINDTESTDATA("data/hi.http"));
                 file.open(QFile::ReadOnly | QFile::Text);
                 socket->write(file.readAll());
@@ -86,8 +92,9 @@ private Q_SLOTS:
         QUrl root("http://localhost");
         root.setPort(t.serverPort());
         HTTPConnection c(root);
-        QUrlQuery query;
+        Query query;
         query.addQueryItem("informal", "yes+certainly");
+        query.addQueryItem("password", "%3C___m&T9zSZ>0,q%FFDN");
         auto job = c.get("/hi", query);
         job->exec();
         QCOMPARE(job->data(), "Hello!\n");
